@@ -597,6 +597,37 @@ def table_column(
     )
 
 
+@translate.register(ops.StructField)
+def struct_field(
+    op: ops.StructField,
+    _: ir.ColumnExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    child = translate(op.arg, compiler=compiler, **kwargs)
+    field_name = op.field
+    # TODO: store names/types inverse mapping on datatypes.Struct for O(1)
+    # access to field index
+    field_index = op.arg.type().names.index(field_name)
+
+    struct_field = child.selection.direct_reference.struct_field
+
+    # keep digging until we bottom out on the deepest child reference which
+    # becomes the parent for the returned reference
+    while struct_field.HasField("child"):
+        struct_field = struct_field.child.struct_field
+
+    struct_field.child.MergeFrom(
+        stalg.Expression.ReferenceSegment(
+            struct_field=stalg.Expression.ReferenceSegment.StructField(
+                field=field_index
+            )
+        )
+    )
+
+    return child
+
+
 @translate.register(ops.UnboundTable)
 def unbound_table(
     op: ops.UnboundTable, expr: ir.TableExpr, _: SubstraitCompiler, **kwargs: Any
@@ -875,3 +906,40 @@ def aggregation(
     )
 
     return stalg.Rel(aggregate=aggregate)
+
+
+@translate.register(ops.SimpleCase)
+def _simple_case(
+    op: ops.SimpleCase,
+    expr: ir.TableExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    # the field names for an `if_then` are `if` and `else` which means we need
+    # to pass those args in as a dictionary to not run afoul of SyntaxErrors`
+    _ifs = []
+    for case, result in zip(op.cases, op.results):
+        _if = {
+            "if": translate(op.base == case, compiler, **kwargs),
+            "then": translate(result, compiler, **kwargs),
+        }
+        _ifs.append(stalg.Expression.IfThen.IfClause(**_if))
+
+    _else = {"else": translate(op.default, compiler, **kwargs)}
+
+    return stalg.Expression(if_then=stalg.Expression.IfThen(ifs=_ifs, **_else))
+
+
+@translate.register(ops.Contains)
+def _contains(
+    op: ops.Contains,
+    expr: ir.TableExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    return stalg.Expression(
+        singular_or_list=stalg.Expression.SingularOrList(
+            value=translate(op.value, compiler, **kwargs),
+            options=[translate(value, compiler, **kwargs) for value in op.options],
+        )
+    )
