@@ -205,3 +205,36 @@ def test_decompile_right_join_ibis2(t, s, compiler):
     plan = compiler.compile(expr)
     (result,) = decompile(plan)
     assert result.equals(expr)
+
+
+def test_nested_struct_field_access(compiler):
+    t = ibis.table(
+        dict(a="struct<b: struct<c: int64, d: struct<e: int64, f: int64, g: int64>>>")
+    )
+    expr = t[t.a["b"]["d"]["g"]]
+    plan = compiler.compile(expr)
+    (result,) = decompile(plan)
+    assert result.equals(expr)
+
+
+@pytest.mark.skipif(
+    version.parse(ibis.__version__) < version.parse("3.0.0"),
+    reason="We look forwards, not backwards",
+)
+def test_decompile_if_then(t, compiler):
+    expr = t.groupby(t.a).aggregate(
+        val=t.d.case().when(3, 1).when(2, 1).else_(0).end().sum()
+    )
+    plan = compiler.compile(expr)
+    (result,) = decompile(plan)
+    assert result.equals(expr)
+
+
+def test_singular_or_list(compiler):
+    t = ibis.table([("bork", dt.string)], name="t")
+
+    expr = t.filter(t.bork.isin(["ork", "bork"]))
+
+    plan = compiler.compile(expr)
+    (result,) = decompile(plan)
+    assert result.equals(expr)
